import { IResource, Resource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { IReceiptRuleAction } from './receipt-rule-action';
import { IReceiptRuleSet } from './receipt-rule-set';
import { Construct as CoreConstruct } from '@aws-cdk/core';
/**
 * A receipt rule.
 *
 * @stability stable
 */
export interface IReceiptRule extends IResource {
    /**
     * The name of the receipt rule.
     *
     * @stability stable
     * @attribute true
     */
    readonly receiptRuleName: string;
}
/**
 * The type of TLS policy for a receipt rule.
 *
 * @stability stable
 */
export declare enum TlsPolicy {
    /**
     * Do not check for TLS.
     *
     * @stability stable
     */
    OPTIONAL = "Optional",
    /**
     * Bounce emails that are not received over TLS.
     *
     * @stability stable
     */
    REQUIRE = "Require"
}
/**
 * Options to add a receipt rule to a receipt rule set.
 *
 * @stability stable
 */
export interface ReceiptRuleOptions {
    /**
     * An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
     *
     * @default - No actions.
     * @stability stable
     */
    readonly actions?: IReceiptRuleAction[];
    /**
     * An existing rule after which the new rule will be placed.
     *
     * @default - The new rule is inserted at the beginning of the rule list.
     * @stability stable
     */
    readonly after?: IReceiptRule;
    /**
     * Whether the rule is active.
     *
     * @default true
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * The name for the rule.
     *
     * @default - A CloudFormation generated name.
     * @stability stable
     */
    readonly receiptRuleName?: string;
    /**
     * The recipient domains and email addresses that the receipt rule applies to.
     *
     * @default - Match all recipients under all verified domains.
     * @stability stable
     */
    readonly recipients?: string[];
    /**
     * Whether to scan for spam and viruses.
     *
     * @default false
     * @stability stable
     */
    readonly scanEnabled?: boolean;
    /**
     * Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
     *
     * @default - Optional which will not check for TLS.
     * @stability stable
     */
    readonly tlsPolicy?: TlsPolicy;
}
/**
 * Construction properties for a ReceiptRule.
 *
 * @stability stable
 */
export interface ReceiptRuleProps extends ReceiptRuleOptions {
    /**
     * The name of the rule set that the receipt rule will be added to.
     *
     * @stability stable
     */
    readonly ruleSet: IReceiptRuleSet;
}
/**
 * A new receipt rule.
 *
 * @stability stable
 */
export declare class ReceiptRule extends Resource implements IReceiptRule {
    /**
     * @stability stable
     */
    static fromReceiptRuleName(scope: Construct, id: string, receiptRuleName: string): IReceiptRule;
    /**
     * The name of the receipt rule.
     *
     * @stability stable
     */
    readonly receiptRuleName: string;
    private readonly actions;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: ReceiptRuleProps);
    /**
     * Adds an action to this receipt rule.
     *
     * @stability stable
     */
    addAction(action: IReceiptRuleAction): void;
    private renderActions;
}
/**
 * @stability stable
 */
export interface DropSpamReceiptRuleProps extends ReceiptRuleProps {
}
/**
 * A rule added at the top of the rule set to drop spam/virus.
 *
 * @see https://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email-action-lambda-example-functions.html
 * @stability stable
 */
export declare class DropSpamReceiptRule extends CoreConstruct {
    /**
     * @stability stable
     */
    readonly rule: ReceiptRule;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: DropSpamReceiptRuleProps);
}
